@@ -3,7 +3,8 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
   #==============================================================
   perc = 0.1; inbedthreshold = 15; bedblocksize = 30; outofbedsize = 60 # default configurations (keep hardcoded for now
 
-  sptwindow_HDCZA = function(angle, k =60, perc = 0.1, inbedthreshold = 15, bedblocksize = 30, outofbedsize = 60, ws3 = 5, constrain2range = FALSE) {
+  sptwindow_HDCZA = function(angle, k =60, perc = 0.1, inbedthreshold = 15, 
+                             bedblocksize = 30, outofbedsize = 60, ws3 = 5, constrain2range = FALSE) {
     medabsdi = function(angle) {
       angvar = stats::median(abs(diff(angle))) #50th percentile, do not use mean because that will be outlier dependent
       return(angvar)
@@ -55,48 +56,52 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
       e5 = which(diff(c(0,inbedtime2,0)) == -1) #end blocks out of bed?
       inbeddurations = e5 - s5
       longestinbed = which(inbeddurations == max(inbeddurations))
-      lightsout = s5[longestinbed] - 1
-      lightson = e5[longestinbed] - 1
-      if (lightsout == 0) lightsout = 1
+      sptwindow_HDCZA_start = s5[longestinbed] - 1
+      sptwindow_HDCZA_end = e5[longestinbed] - 1
+      if (sptwindow_HDCZA_start == 0) sptwindow_HDCZA_start = 1
     } else {
-      lightson = c()
-      lightsout = c()
+      sptwindow_HDCZA_end = c()
+      sptwindow_HDCZA_start = c()
       tib.threshold = c()
     }
     tib.threshold = pp
-    invisible(list(lightsout=lightsout,lightson=lightson,tib.threshold=tib.threshold))
+    invisible(list(sptwindow_HDCZA_start=sptwindow_HDCZA_start, 
+                   sptwindow_HDCZA_end=sptwindow_HDCZA_end, tib.threshold=tib.threshold))
   }
-  dstime_handling_check = function(tmpTIME=tmpTIME,inbedout=inbedout,tz=c(),calc_lightson=c(),calc_lightsout=c()) {
-    time_lightsout =iso8601chartime2POSIX(tmpTIME[inbedout$lightsout],tz=tz)
-    time_lightson =iso8601chartime2POSIX(tmpTIME[inbedout$lightson],tz=tz)
-    time_lightson_hr = as.numeric(format(time_lightson, format = "%H"))
-    time_lightsout_hr = as.numeric(format(time_lightsout, format = "%H"))
+  dstime_handling_check = function(tmpTIME=tmpTIME,inbedout=inbedout,tz=c(), 
+                                   calc_sptwindow_HDCZA_end=c(), calc_sptwindow_HDCZA_start=c()) {
+    time_sptwindow_HDCZA_start =iso8601chartime2POSIX(tmpTIME[inbedout$sptwindow_HDCZA_start],tz=tz)
+    time_sptwindow_HDCZA_end =iso8601chartime2POSIX(tmpTIME[inbedout$sptwindow_HDCZA_end],tz=tz)
+    time_sptwindow_HDCZA_end_hr = as.numeric(format(time_sptwindow_HDCZA_end, format = "%H"))
+    time_sptwindow_HDCZA_start_hr = as.numeric(format(time_sptwindow_HDCZA_start, format = "%H"))
     t0 = as.numeric(format(iso8601chartime2POSIX(tmpTIME[1],tz=tz), format = "%H"))
     t1 = as.numeric(format(iso8601chartime2POSIX(tmpTIME[length(tmpTIME)],tz=tz), format = "%H"))
     if (is.na(t1) == TRUE | is.na(t0) == TRUE) { 
       # if timestamp is stored in POSIX format (older versions of GGIR prior 2017)
       # for example when milestone data generated by old packages is now processed
       # then this part of the code is to facilitate consistency
-      time_lightsout =as.POSIXlt(tmpTIME[inbedout$lightsout],origin="1970-01-01",tz=tz)
-      time_lightson =as.POSIXlt(tmpTIME[inbedout$lightson],origin="1970-01-01",tz=tz)
-      time_lightson_hr = as.numeric(format(time_lightson, format = "%H"))
-      time_lightsout_hr = as.numeric(format(time_lightsout, format = "%H"))
+      time_sptwindow_HDCZA_start =as.POSIXlt(tmpTIME[inbedout$sptwindow_HDCZA_start],origin="1970-01-01",tz=tz)
+      time_sptwindow_HDCZA_end =as.POSIXlt(tmpTIME[inbedout$sptwindow_HDCZA_end],origin="1970-01-01",tz=tz)
+      time_sptwindow_HDCZA_end_hr = as.numeric(format(time_sptwindow_HDCZA_end, format = "%H"))
+      time_sptwindow_HDCZA_start_hr = as.numeric(format(time_sptwindow_HDCZA_start, format = "%H"))
       t0 = as.numeric(format(as.POSIXlt(tmpTIME[1],origin="1970-01-01",tz=tz), format = "%H"))
       t1 = as.numeric(format(as.POSIXlt(tmpTIME[length(tmpTIME)],origin="1970-01-01",tz=tz), format = "%H"))
     }
     Nhoursdata = floor(length(tmpTIME) / (3600/ws3))
     delta_t1_t0 = (t1+24) - t0
-    if (length(time_lightson_hr) > 0 & length(time_lightsout_hr) > 0) {
-      if (Nhoursdata > (delta_t1_t0 + 0.1) &  # time has moved backward (autumn)  so lightson also needs to move backward
-          (time_lightson_hr > 1 | time_lightson_hr < 12) & (time_lightsout_hr < 1 | time_lightsout_hr > 12)) { #extra DST hour not recognized
-        calc_lightson = calc_lightson - 1
-      } else if (Nhoursdata + 0.1 < delta_t1_t0 &  # time has moved forward (spring) so lightson also needs to move forward
-                 (time_lightson_hr > 1 | time_lightson_hr < 12) & (time_lightsout_hr < 1 | time_lightsout_hr > 12)) { #missing DST hour not recognized
-        calc_lightson = calc_lightson + 1
+    if (length(time_sptwindow_HDCZA_end_hr) > 0 & length(time_sptwindow_HDCZA_start_hr) > 0) {
+      if (Nhoursdata > (delta_t1_t0 + 0.1) &  # time has moved backward (autumn)  so sptwindow_HDCZA_end also needs to move backward
+          (time_sptwindow_HDCZA_end_hr > 1 | time_sptwindow_HDCZA_end_hr < 12) & 
+          (time_sptwindow_HDCZA_start_hr < 1 | time_sptwindow_HDCZA_start_hr > 12)) { #extra DST hour not recognized
+        calc_sptwindow_HDCZA_end = calc_sptwindow_HDCZA_end - 1
+      } else if (Nhoursdata + 0.1 < delta_t1_t0 &  # time has moved forward (spring) so sptwindow_HDCZA_end also needs to move forward
+                 (time_sptwindow_HDCZA_end_hr > 1 | time_sptwindow_HDCZA_end_hr < 12) & 
+                 (time_sptwindow_HDCZA_start_hr < 1 | time_sptwindow_HDCZA_start_hr > 12)) { #missing DST hour not recognized
+        calc_sptwindow_HDCZA_end = calc_sptwindow_HDCZA_end + 1
       }
     }
     
-    return(calc_lightson)
+    return(calc_sptwindow_HDCZA_end)
   }
   #==================================================
   # get variables  
@@ -153,7 +158,6 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
         # count posture changes that happen less than once per ten minutes
         q1 = c()
         if (length(postch) > 1) {
-          
           q1 = which(diff(postch) > (i*(60/ws3))) #less than once per i minutes
         }
         if (length(q1) > 0) {
@@ -187,7 +191,7 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
     midnightsi=detemout$midnightsi
     countmidn = length(midnightsi)
     
-    tib.threshold = lightson = lightsout = L5list = rep(0,countmidn)
+    tib.threshold = sptwindow_HDCZA_end = sptwindow_HDCZA_start = L5list = rep(0,countmidn)
     if (countmidn != 0) {
       if (countmidn == 1) {
         tooshort = 1
@@ -206,13 +210,14 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
         tmpANGLE = angle[qqq1:qqq2]
         tmpTIME = time[qqq1:qqq2]
         inbedout = sptwindow_HDCZA(tmpANGLE,ws3=ws3,constrain2range=constrain2range, 
-                                   perc = perc, inbedthreshold = inbedthreshold, bedblocksize = bedblocksize, outofbedsize = outofbedsize)
-        if (length(inbedout$lightson) > 0 & length(inbedout$lightsout) > 0) {
-          lightson[1] = inbedout$lightson
-          lightsout[1] = inbedout$lightsout
-          lightson[1] = dstime_handling_check(tmpTIME=tmpTIME,inbedout=inbedout,
-                                              tz=desiredtz,calc_lightson=lightson[1],
-                                              calc_lightsout=lightsout[1])
+                                   perc = perc, inbedthreshold = inbedthreshold, bedblocksize = bedblocksize, 
+                                   outofbedsize = outofbedsize)
+        if (length(inbedout$sptwindow_HDCZA_end) > 0 & length(inbedout$sptwindow_HDCZA_start) > 0) {
+          sptwindow_HDCZA_end[1] = inbedout$sptwindow_HDCZA_end
+          sptwindow_HDCZA_start[1] = inbedout$sptwindow_HDCZA_start
+          sptwindow_HDCZA_end[1] = dstime_handling_check(tmpTIME=tmpTIME,inbedout=inbedout,
+                                              tz=desiredtz,calc_sptwindow_HDCZA_end=sptwindow_HDCZA_end[1],
+                                              calc_sptwindow_HDCZA_start=sptwindow_HDCZA_start[1])
           tib.threshold[1] = inbedout$tib.threshold
         }
         
@@ -271,13 +276,14 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
           tmpANGLE = angle[qqq1:qqq2]
           tmpTIME = time[qqq1:qqq2]
           inbedout = sptwindow_HDCZA(tmpANGLE,ws3=ws3,constrain2range=constrain2range,
-                                     perc = perc, inbedthreshold = inbedthreshold, bedblocksize = bedblocksize, outofbedsize = outofbedsize)
-          if (length(inbedout$lightson) != 0 & length(inbedout$lightsout) != 0) {
-            lightson[j] = (inbedout$lightson / (3600/ ws3)) + 12
-            lightsout[j] = (inbedout$lightsout / (3600/ ws3)) + 12
-            lightson[j] = dstime_handling_check(tmpTIME=tmpTIME,inbedout=inbedout,
-                                                tz=desiredtz,calc_lightson=lightson[j],
-                                                calc_lightsout=lightsout[j])
+                                     perc = perc, inbedthreshold = inbedthreshold, 
+                                     bedblocksize = bedblocksize, outofbedsize = outofbedsize)
+          if (length(inbedout$sptwindow_HDCZA_end) != 0 & length(inbedout$sptwindow_HDCZA_start) != 0) {
+            sptwindow_HDCZA_end[j] = (inbedout$sptwindow_HDCZA_end / (3600/ ws3)) + 12
+            sptwindow_HDCZA_start[j] = (inbedout$sptwindow_HDCZA_start / (3600/ ws3)) + 12
+            sptwindow_HDCZA_end[j] = dstime_handling_check(tmpTIME=tmpTIME,inbedout=inbedout,
+                                                tz=desiredtz,calc_sptwindow_HDCZA_end=sptwindow_HDCZA_end[j],
+                                                calc_sptwindow_HDCZA_start=sptwindow_HDCZA_start[j])
             tib.threshold[j] = inbedout$tib.threshold
           }
         }
@@ -287,16 +293,16 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
       cat("No midnights found")
       detection.failed = TRUE
     }
-    
     metatmp = data.frame(time,invalid,night=night,sleep = sleep)
   } else {
     metatmp =c()
     L5list = c()
-    lightson = c()
-    lightsout = c()
+    sptwindow_HDCZA_end = c()
+    sptwindow_HDCZA_start = c()
     tib.threshold = c()
     detection.failed = TRUE
   }
-  
-  invisible(list(output = metatmp,detection.failed=detection.failed,L5list=L5list,lightson =lightson,lightsout=lightsout,tib.threshold=tib.threshold))
+  invisible(list(output = metatmp, detection.failed=detection.failed, L5list=L5list, 
+                 sptwindow_HDCZA_end =sptwindow_HDCZA_end, sptwindow_HDCZA_start=sptwindow_HDCZA_start,
+                 tib.threshold=tib.threshold))
 }
